=====
hhycommon
=====

hhycommon project is coin application for hehuoya.com


Quick start
-----------

1,配置aes密钥
在settings.py中。AES_SECRET_KEY='AES key must be either 16, 24, or 32 bytes long'

  pip3 install Crypto
  
 
  